@@ -17,7 +17,6 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
 import sys
 from collections.abc import Callable
 from gettext import gettext as _
@@ -71,7 +70,6 @@ class Application(Adw.Application):
         win.present()
 
         if PROFILE == "development":
-            logging.getLogger().setLevel(logging.DEBUG)
             win.add_css_class("devel")
 
     def on_about_action(self, *_args: Any) -> None:
@@ -84,12 +82,12 @@ class Application(Adw.Application):
         about.set_translator_credits(_("translator-credits"))
         about.set_copyright(_("Copyright © 2024 Hari Rana (TheEvilSkeleton)"))
 
-        about.add_other_app(  # type: ignore [attr-defined]
+        about.add_other_app(
             "com.usebottles.bottles",
             _("Bottles"),
             _("Run Windows software"),
         )
-        about.add_other_app(  # type: ignore [attr-defined]
+        about.add_other_app(
             "io.gitlab.theevilskeleton.Upscaler",
             _("Upscaler"),
             _("Upscale and enhance images"),
@@ -120,7 +118,7 @@ class Application(Adw.Application):
             self.set_accels_for_action(f"app.{name}", shortcuts)
 
 
-def main(version: str) -> int:
+def main() -> int:
     """The application's entry point."""
     app = Application()
     return app.run(sys.argv)
