@@ -17,13 +17,16 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
-from gi.repository import Gio, GObject, Gtk, GLib
+from gi.repository import GObject, Gio, Gtk
 
-from refine.widgets.reset_button import ResetButton
+from refine.logger import logger
 from refine.widgets.base import BaseInterface
+from refine.widgets.reset_button import ResetButton
+
+if TYPE_CHECKING:
+    from gi.repository import GLib
 
 
 class Adjustment(Gtk.Adjustment, BaseInterface):
@@ -35,11 +38,11 @@ class Adjustment(Gtk.Adjustment, BaseInterface):
 
     __gtype_name__ = "Adjustment"
 
-    settings = cast(Gio.Settings, GObject.Property(type=Gio.Settings))
-    schema_id = cast(str, GObject.Property(type=str))
-    schema = cast(Gio.SettingsSchema, GObject.Property(type=Gio.SettingsSchema))
-    key = cast(str, GObject.Property(type=str))
-    is_valid_setting = cast(bool, GObject.Property(type=bool, default=False))
+    settings = cast("Gio.Settings", GObject.Property(type=Gio.Settings))
+    schema_id = cast("str", GObject.Property(type=str))
+    schema = cast("Gio.SettingsSchema", GObject.Property(type=Gio.SettingsSchema))
+    key = cast("str", GObject.Property(type=str))
+    is_valid_setting = cast("bool", GObject.Property(type=bool, default=False))
 
     revealer = GObject.Property(type=Gtk.Revealer)
     reset_button = GObject.Property(type=ResetButton)
@@ -51,7 +54,7 @@ class Adjustment(Gtk.Adjustment, BaseInterface):
         BaseInterface.__init__(self, **kwargs)
 
     def _reset_button_clicked(self, *_args: Any) -> None:
-        logging.debug("Revert button pressed")
+        logger.debug("Revert button pressed")
         self.settings.reset(self.key)
         self.set_value(self.settings.get_int(self.key))
         self.do_update()
@@ -65,7 +68,7 @@ class Adjustment(Gtk.Adjustment, BaseInterface):
         type Range = tuple[Any, tuple[int, int]]
 
         schema_key = self.schema.get_key(self.key)
-        variant = cast(Range, schema_key.get_range())
+        variant = cast("Range", schema_key.get_range())
         range = variant[1]
 
         self.set_lower(range[0])
@@ -78,7 +81,7 @@ class Adjustment(Gtk.Adjustment, BaseInterface):
         BaseInterface.set_up_separator_revealer(self.revealer, self.reset_button)
 
     def do_update(self) -> None:
-        default_value = cast(GLib.Variant, self.settings.get_default_value(self.key))
+        default_value = cast("GLib.Variant", self.settings.get_default_value(self.key))
         default_int = default_value.get_int32()
         value = int(self.get_value())
 
@@ -86,4 +89,4 @@ class Adjustment(Gtk.Adjustment, BaseInterface):
 
     def value_set(self, value: Any) -> None:
         """Log key-value pair."""
-        logging.debug(f"Set key “{self.key}” to “{value}”")
+        logger.debug(f"Set key “{self.key}” to “{value}”")
