@@ -17,13 +17,16 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
-from gi.repository import Adw, Gio, GObject, Gtk, GLib
+from gi.repository import Adw, GObject, Gio, Gtk
 
+from refine.logger import logger
 from refine.widgets.base import BaseInterface
 
+if TYPE_CHECKING:
+    from gi.repository import GLib
+
 
 class ComboRow(Adw.ComboRow, BaseInterface):
     """
@@ -34,11 +37,11 @@ class ComboRow(Adw.ComboRow, BaseInterface):
 
     __gtype_name__ = "ComboRow"
 
-    is_valid_setting = cast(bool, GObject.Property(type=bool, default=False))
-    settings = cast(Gio.Settings, GObject.Property(type=Gio.Settings))
-    schema = cast(Gio.SettingsSchema, GObject.Property(type=Gio.SettingsSchema))
-    schema_id = cast(str, GObject.Property(type=str))
-    key = cast(str, GObject.Property(type=str))
+    is_valid_setting = cast("bool", GObject.Property(type=bool, default=False))
+    settings = cast("Gio.Settings", GObject.Property(type=Gio.Settings))
+    schema = cast("Gio.SettingsSchema", GObject.Property(type=Gio.SettingsSchema))
+    schema_id = cast("str", GObject.Property(type=str))
+    key = cast("str", GObject.Property(type=str))
 
     restart_required = GObject.Property(type=bool, default=False)
     is_default = GObject.Property(type=bool, default=True)
@@ -66,10 +69,10 @@ class ComboRow(Adw.ComboRow, BaseInterface):
         self.handler_unblock_by_func(self.selected_callback)  # type: ignore [no-untyped-call]
 
     def _reset_button_clicked(self, *_args: Any) -> None:
-        logging.debug("Revert button pressed")
+        logger.debug("Revert button pressed")
 
         string_object = cast(
-            Gtk.StringObject, self.settings.get_default_value(self.key)
+            "Gtk.StringObject", self.settings.get_default_value(self.key)
         )
         if not string_object:
             return
@@ -82,7 +85,7 @@ class ComboRow(Adw.ComboRow, BaseInterface):
 
     def set_is_default(self, key: str) -> None:
         """Update the `ComboRow.is-default` property."""
-        default_value = cast(GLib.Variant, self.settings.get_default_value(key))
+        default_value = cast("GLib.Variant", self.settings.get_default_value(key))
         default_string = default_value.get_string()
 
         row_string = self.original_list[self.get_selected()]
@@ -99,7 +102,7 @@ class ComboRow(Adw.ComboRow, BaseInterface):
 
     def value_set(self, value: Any) -> None:
         """Log key-value pair."""
-        logging.debug(f"Set key “{self.key}” to “{value}”")
+        logger.debug(f"Set key “{self.key}” to “{value}”")
 
         if not self.restart_required:
             return
@@ -126,4 +129,4 @@ class ComboRow(Adw.ComboRow, BaseInterface):
     @GObject.Signal
     def inconsistent(self) -> None:
         """Log inconsistency signal."""
-        logging.info(f"{self.__class__.__name__}::inconsistent signal emitted")
+        logger.info(f"{self.__class__.__name__}::inconsistent signal emitted")
