@@ -17,12 +17,13 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
+import contextlib
 from typing import Any, cast
 
 from gi.repository import Gtk
 
-from refine.widgets.string_row import StringRow
 from refine.widgets.base import InvalidSettingError
+from refine.widgets.string_row import StringRow
 
 
 @Gtk.Template.from_resource("/page/tesk/Refine/widgets/flags-switch-row.ui")
@@ -39,14 +40,12 @@ class FlagsSwitchRow(StringRow):
         """Set whether @self is in its “on” or “off” position."""
         flags = self.get_string()
 
-        value = cast(str, self.value)
+        value = cast("str", self.value)
         if self.active:
             flags.append(value)
         else:
-            try:
+            with contextlib.suppress(ValueError):
                 flags.remove(value)
-            except ValueError:
-                pass
 
         flags = list(set(flags))
 
@@ -62,6 +61,6 @@ class FlagsSwitchRow(StringRow):
             key_range = schema_key.get_range()[1]
 
             if self.value not in key_range:
-                raise TypeError
-        except (IndexError, TypeError):
-            raise InvalidSettingError
+                raise InvalidSettingError
+        except (IndexError, TypeError) as error:
+            raise InvalidSettingError from error
