@@ -17,17 +17,16 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from typing import Any
-
 from gettext import gettext as _
+from typing import Any
 
 from gi.repository import Gtk
 
 
-class RefineResetButton(Gtk.Button):
+class ResetButton(Gtk.Button):
     """A `Gtk.Button` for resetting a setting."""
 
-    __gtype_name__ = "RefineResetButton"
+    __gtype_name__ = "ResetButton"
 
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(**kwargs)
