@@ -20,8 +20,10 @@
 
 from gi.repository import GObject, Gtk
 
-from refine.widgets.combo_row import ComboRow
 from refine.widgets.base import InvalidSettingError
+from refine.widgets.combo_row import ComboRow
+
+MINIMUM_CHILDREN = 2
 
 
 @Gtk.Template.from_resource("/page/tesk/Refine/widgets/value-combo-row.ui")
@@ -41,7 +43,7 @@ class ValueComboRow(ComboRow):
         enum_tuple: tuple[str, list[str]] = (
             self.schema.get_key(self.key).get_range().unpack()
         )
-        if len(enum_tuple) < 2 or enum_tuple[0] != "enum":
+        if len(enum_tuple) < MINIMUM_CHILDREN or enum_tuple[0] != "enum":
             raise InvalidSettingError
 
         self.original_list = enum_tuple[1]
@@ -50,32 +52,25 @@ class ValueComboRow(ComboRow):
 
         if self.omit_words:
             for word in self.omit_words.split():
-                word = word.lower()
-                self.transformed_list = list(
-                    map(
-                        lambda string: string.replace(word, ""),
-                        self.transformed_list,
-                    )
-                )
+                self.transformed_list = [
+                    string.replace(word.lower(), "") for string in self.transformed_list
+                ]
 
         if self.omit_hyphens:
-            self.transformed_list = list(
-                map(
-                    lambda string: string.replace("-", " "),
-                    self.transformed_list,
-                )
-            )
+            self.transformed_list = [
+                string.replace("-", " ") for string in self.transformed_list
+            ]
 
         if self.title_case:
-            self.transformed_list = list(map(str.title, self.transformed_list))
+            self.transformed_list = [string.title() for string in self.transformed_list]
 
-        self.transformed_list = list(
-            map(lambda string: string.strip(), self.transformed_list)
+        self.transformed_list = [string.strip() for string in self.transformed_list]
+
+        combined_lists = sorted(
+            zip(self.transformed_list, self.original_list, strict=False)
         )
-
-        combined_lists = sorted(list(zip(self.transformed_list, self.original_list)))
-        self.transformed_list = list(map(lambda item: item[0], combined_lists))
-        self.original_list = list(map(lambda item: item[1], combined_lists))
+        self.transformed_list = [string[0] for string in combined_lists]
+        self.original_list = [string[1] for string in combined_lists]
 
         model = Gtk.StringList.new(self.transformed_list)
         string: str = self.settings.get_string(self.key)
