@@ -17,17 +17,20 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
 from collections.abc import Callable
 from gettext import gettext as _
 from typing import Any, cast
 
-from gi.repository import Adw, Gdk, Gio, GLib, GObject, Gtk
+from gi.repository import Adw, GLib, GObject, Gdk, Gio, Gtk
 
+from refine.logger import logger
 from refine.typing import LogicalDirectionType
 from refine.widgets.base import BaseInterface
 
 
+class ButtonNotFoundError(AssertionError): ...
+
+
 class WindowMenuButton(Gtk.Button):
     __gtype_name__ = "WindowMenuButton"
 
@@ -82,7 +85,7 @@ class WindowMenuButton(Gtk.Button):
             case (Gtk.DirectionType.RIGHT, Gtk.TextDirection.RTL):
                 return LogicalDirectionType.START
             case _:
-                assert False
+                raise AssertionError
         # fmt: on
 
     def _hidden_item_menu(self) -> Gio.Menu:
@@ -129,7 +132,7 @@ class WindowMenuButton(Gtk.Button):
                 case LogicalDirectionType.END:
                     sibling = sibling.get_next_sibling()  # type: ignore [assignment]
                 case _:
-                    assert False
+                    raise AssertionError
             if sibling is None:
                 return None
             if type(sibling) is WindowMenuButton:
@@ -168,7 +171,7 @@ class WindowButtonBin(Adw.Bin):
         pass
 
     def __init__(self, **kwargs: Any) -> None:
-        self.props.css_name = "windowbuttonbox"
+        self.set_css_name("windowbuttonbox")
         super().__init__(**kwargs)
         self.connect("notify::button-layout", self._button_layout_set_callback)
 
@@ -264,15 +267,13 @@ class WindowButtonBin(Adw.Bin):
         if child is None:
             if self.alignment is Gtk.Align.END:
                 return None
-            else:
-                return self.button_box.get_last_child()
+            return self.button_box.get_last_child()
 
         child_width = child.get_width()
 
         if (x % child_width) > child_width / 2:
             return child
-        else:
-            return child.get_prev_sibling()
+        return child.get_prev_sibling()
 
     def _get_box_child(self, child: Gtk.Widget) -> Gtk.Widget | None:
         if child is self:
@@ -292,9 +293,8 @@ class WindowButtonBin(Adw.Bin):
 
         while child is not None:
             child = child.get_next_sibling()
-            if type(child) is WindowMenuButton:
-                if child.button_id == button_id:
-                    return child
+            if type(child) is WindowMenuButton and child.button_id == button_id:
+                return child
 
         return None
 
@@ -324,11 +324,11 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
     hidden_box = Gtk.Template.Child()
     reset_button = Gtk.Template.Child()
 
-    settings = cast(Gio.Settings, GObject.Property(type=Gio.Settings))
-    schema_id = cast(str, GObject.Property(type=str))
-    schema = cast(Gio.SettingsSchema, GObject.Property(type=Gio.SettingsSchema))
-    key = cast(str, GObject.Property(type=str))
-    is_valid_setting = cast(bool, GObject.Property(type=bool, default=False))
+    settings = cast("Gio.Settings", GObject.Property(type=Gio.Settings))
+    schema_id = cast("str", GObject.Property(type=str))
+    schema = cast("Gio.SettingsSchema", GObject.Property(type=Gio.SettingsSchema))
+    key = cast("str", GObject.Property(type=str))
+    is_valid_setting = cast("bool", GObject.Property(type=bool, default=False))
 
     is_default = GObject.Property(type=bool, default=True)
     button_layout = GObject.Property(type=str, default="")
@@ -365,14 +365,15 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
                 if button_sibling is None and box.next_box is not None:
                     box.next_box.add_button(button)
             case _:
-                logging.error("Unsupported alignment used in move_item")
+                logger.error("Unsupported alignment used in move_item")
 
     def _show_item(self, _widget: Any, _action_name: str, variant: Any) -> None:
         (button_id, alignment) = variant.unpack()
         alignment = LogicalDirectionType(alignment)
         button = self.hidden_box.pick_button(button_id)
 
-        assert button is not None
+        if not button:
+            raise ButtonNotFoundError(button_id)
 
         match alignment:
             case LogicalDirectionType.START:
@@ -380,7 +381,7 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
             case LogicalDirectionType.END:
                 self.end_box.add_button(button)
             case _:
-                logging.error("Unsupported alignment used in show_item")
+                logger.error("Unsupported alignment used in show_item")
 
     def _hide_item(self, _widget: Any, _action_name: str, variant: Any) -> None:
         button_id = variant.unpack()
@@ -388,7 +389,9 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
 
         if button is None:
             button = self.end_box.pick_button(button_id)
-        assert button is not None
+
+            if button is None:
+                raise ButtonNotFoundError(button_id)
 
         self.hidden_box.add_button(button)
 
@@ -396,8 +399,8 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
         self.start_box.update_layout()
         self.end_box.update_layout()
 
-        layout = ":".join([self.start_box.button_layout, self.end_box.button_layout])
-        logging.debug(f"Set key “{self.key}” to “{layout}”")
+        layout = f"{self.start_box.button_layout}:{self.end_box.button_layout}"
+        logger.debug(f"Set key “{self.key}” to “{layout}”")
 
         self.settings.set_value(self.key, GLib.Variant.new_string(layout))
 
@@ -417,7 +420,7 @@ class WindowButtonsRow(Adw.PreferencesRow, BaseInterface):
         self.reset_button.set_visible(not self.is_default)
 
     def _reset_button_clicked(self, *_args: Any) -> None:
-        logging.debug("Reset button pressed")
+        logger.debug("Reset button pressed")
         self.settings.reset(self.key)
 
     def do_setup(self) -> None:
