@@ -17,22 +17,23 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-import logging
 from gettext import gettext as _
 from typing import Any, cast
 
 from gi.repository import Adw, GLib, GObject, Gtk
 
+from refine.logger import logger
+
 # ruff: noqa: F401
 from refine.widgets.adjustment import Adjustment
 from refine.widgets.base import BaseInterface
+from refine.widgets.boolean_switch_row import BooleanSwitchRow
 from refine.widgets.combo_row import ComboRow
 from refine.widgets.data_combo_row import DataComboRow
 from refine.widgets.flags_switch_row import FlagsSwitchRow
 from refine.widgets.font_row import FontRow
 from refine.widgets.panel_row import PanelRow
 from refine.widgets.reset_button import ResetButton
-from refine.widgets.boolean_switch_row import BooleanSwitchRow
 from refine.widgets.value_combo_row import ValueComboRow
 from refine.widgets.value_switch_row import ValueSwitchRow
 from refine.widgets.window_buttons_row import WindowButtonsRow
@@ -83,8 +84,7 @@ class Window(Adw.ApplicationWindow):
     def _create_row_func(self, panel: Gtk.StringObject, *_args: Any) -> Gtk.Widget:
         builder = Gtk.Builder.new_from_resource(panel.get_string())
         row = PanelRow()
-        if not (page := builder.get_object("page")):
-            raise TypeError(f"page for {row} missing")
+        page = builder.get_object("page")
 
         row.page = page  # type: ignore [method-assign]
 
@@ -140,14 +140,14 @@ class Window(Adw.ApplicationWindow):
     # TODO: Find a way to request a logout dialog
     @GObject.Signal
     def restart_items_changed(self, widget: Gtk.Widget) -> None:
-        logging.info(f"{self.__class__.__name__}::restart-items-changed signal emitted")
+        logger.info(f"{self.__class__.__name__}::restart-items-changed signal emitted")
 
-        if not (panel := cast(PanelPage, widget.get_ancestor(PanelPage))):
+        if not (panel := cast("PanelPage", widget.get_ancestor(PanelPage))):
             return
 
         try:
-            if not (banner := panel.get_banner()):  # type: ignore [attr-defined]
-                raise TypeError
+            if not (banner := panel.get_banner()):
+                return
         except (AttributeError, TypeError):
             return
 
